@@ -50,8 +50,8 @@ if __name__ == '__main__':
           scripts = $scripts,
           packages = $packages,
           classifiers = $classifiers,
-          $data_files
-          $package_data
+          $data_files   #  data files
+          $package_data   # package data
           $dependencies
           $dependency_links
           zip_safe=True
@@ -67,8 +67,7 @@ def default(value, default=""):
 
 @init
 def initialize_distutils_plugin(project):
-    project.set_property_if_unset(
-        "distutils_commands", ["sdist", "bdist_dumb"])
+    project.set_property_if_unset("distutils_commands", ["sdist", "bdist_dumb"])
     project.set_property_if_unset("distutils_classifiers", [
         "Development Status :: 3 - Alpha",
         "Programming Language :: Python"
